@@ -43,23 +43,19 @@ public class HttpSessionFacade implements ISession {
 
     private HttpSession session;
     private int timeout;
-    private HttpServletRequest req=null;
     private HttpSession sessionCache=null;
     private boolean isNew;
-    private ServletContext ctx;
-    private HttpServletResponse res;
+    private ServletContextFactory ctxFactory;
     
-    private HttpSession getSession() {
+    HttpSession getCachedSession() {
 	if(sessionCache!=null) return sessionCache;
 	sessionCache = session;
 	sessionCache.setMaxInactiveInterval(timeout);
 	return sessionCache;
     }
-    protected HttpSessionFacade (ServletContext ctx, HttpServletRequest req, HttpServletResponse res, int timeout) {
-	this.session = req.getSession();
-	this.req = req;
-	this.ctx = ctx;
-	this.res = res;
+    protected HttpSessionFacade (ServletContextFactory ctxFactory, ServletContext ctx, HttpServletRequest req, HttpServletResponse res, boolean clientIsNew, int timeout) {
+	this.ctxFactory = ctxFactory;
+	this.session = clientIsNew? req.getSession(true) : req.getSession();
 	this.timeout = timeout;
 	this.isNew = session.isNew();
     }
@@ -67,53 +63,56 @@ public class HttpSessionFacade implements ISession {
     /**
      * Returns the HttpServletRequest
      * @return The HttpServletRequest.
+     * @deprecated Use {@link Context#getHttpServletRequest()}
      */
     public HttpServletRequest getHttpServletRequest() {
-    	return this.req;
+    	return (HttpServletRequest) ((Context)ctxFactory.getContext()).getHttpServletRequest();
     }
     
     /**
      * Returns the ServletContext
      * @return The ServletContext.
+     * @deprecated Use {@link Context#getServletContext()}
      */
     public ServletContext getServletContext() {
-        return this.ctx;
+        return (ServletContext) ((Context)ctxFactory.getContext()).getServletContext();
     }
     
     /**
      * Returns the ServletResponse
      * @return The ServletResponse.
+     * @deprecated Use {@link Context#getHttpServletResponse()}
      */
     public HttpServletResponse getHttpServletResponse() {
-        return this.res;
+        return (HttpServletResponse) ((Context)ctxFactory.getContext()).getHttpServletResponse();
     }
     /**@inheritDoc*/
     public Object get(Object ob) {
-	return getSession().getAttribute(String.valueOf(ob));
+	return getCachedSession().getAttribute(String.valueOf(ob));
     }
 
     /**@inheritDoc*/
     public void put(Object ob1, Object ob2) {
-	getSession().setAttribute(String.valueOf(ob1), ob2);
+	getCachedSession().setAttribute(String.valueOf(ob1), ob2);
     }
 
     /**@inheritDoc*/
    public Object remove(Object ob) {
 	String key = String.valueOf(ob);
-	Object o = getSession().getAttribute(key);
+	Object o = getCachedSession().getAttribute(key);
 	if(o!=null)
-	    getSession().removeAttribute(key);
+	    getCachedSession().removeAttribute(key);
 	return o;
     }
 
    /**@inheritDoc*/
     public void setTimeout(int timeout) {
-	getSession().setMaxInactiveInterval(timeout);
+	getCachedSession().setMaxInactiveInterval(timeout);
     }
 
     /**@inheritDoc*/
     public int getTimeout() {
-	return getSession().getMaxInactiveInterval();
+	return getCachedSession().getMaxInactiveInterval();
     }
 
     /**@inheritDoc*/
@@ -128,7 +127,7 @@ public class HttpSessionFacade implements ISession {
 
     /**@inheritDoc*/
     public void destroy() {
-	getSession().invalidate();
+	getCachedSession().invalidate();
     }
 
     /**@inheritDoc*/
@@ -142,7 +141,7 @@ public class HttpSessionFacade implements ISession {
 
     /**@inheritDoc*/
     public Map getAll() {
-	HttpSession session = getSession();
+	HttpSession session = getCachedSession();
 	HashMap map = new HashMap();
 	for(Enumeration ee = session.getAttributeNames(); ee.hasMoreElements();) {
 	    Object key = ee.nextElement();
@@ -153,10 +152,10 @@ public class HttpSessionFacade implements ISession {
     }
     /**@inheritDoc*/
     public long getCreationTime() {
-      return getSession().getCreationTime();
+      return getCachedSession().getCreationTime();
     }
     /**@inheritDoc*/
     public long getLastAccessedTime() {
-      return getSession().getLastAccessedTime();
+      return getCachedSession().getLastAccessedTime();
     }
 }
