@@ -28,6 +28,7 @@ import javax.servlet.Servlet;
 import javax.servlet.ServletContext;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
+import javax.servlet.http.HttpSession;
 
 import php.java.bridge.ISession;
 import php.java.bridge.http.IContext;
@@ -57,17 +58,18 @@ public class ServletContextFactory extends php.java.bridge.http.SimpleContextFac
     
     /**
      * Set the HttpServletRequest for session sharing. This implementation does nothing, the proxy must have been set in the constructor.
-     * @see php.java.servlet.RemoteServletContextFactory#setSession(HttpServletRequest) 
+     * @see php.java.servlet.RemoteServletContextFactory#setSessionFactory(HttpServletRequest) 
      * @param req The HttpServletRequest
      */
-    public void setSession(HttpServletRequest req) {
+    protected void setSessionFactory(HttpServletRequest req) {
     }
     public ISession getSession(String name, boolean clientIsNew, int timeout) {
+	if(session != null) return session;
 	 // if name != null return a "named" php session which is not shared with jsp
 	if(name!=null) return super.getSession(name, clientIsNew, timeout);
 	
     	if(proxy==null) throw new NullPointerException("This context "+getId()+" doesn't have a session proxy.");
-	return new HttpSessionFacade(kontext, proxy, res, timeout);
+	return session = new HttpSessionFacade(this, kontext, proxy, res, clientIsNew, timeout);
     }
     
     /**
@@ -98,9 +100,18 @@ public class ServletContextFactory extends php.java.bridge.http.SimpleContextFac
 	IContext ctx = new Context(kontext, req, res);
 	ctx.setAttribute(IContext.SERVLET_CONTEXT, kontext, IContext.ENGINE_SCOPE);
 	ctx.setAttribute(IContext.SERVLET_CONFIG, servlet.getServletConfig(), IContext.ENGINE_SCOPE);
-	ctx.setAttribute(IContext.SERVLET_REQUEST, req, IContext.ENGINE_SCOPE);
-	ctx.setAttribute(IContext.SERVLET_RESPONSE, res, IContext.ENGINE_SCOPE);
 	ctx.setAttribute(IContext.SERVLET, servlet, IContext.ENGINE_SCOPE);
+
+	ctx.setAttribute(IContext.SERVLET_REQUEST, req, IContext.ENGINE_SCOPE);
+	ctx.setAttribute(IContext.SERVLET_RESPONSE, new SimpleHttpServletResponse(res), IContext.ENGINE_SCOPE);
 	return ctx;
     }
+
+    /**
+     * Return the http session handle or null;
+     */
+    public HttpSession getSession() {
+	if(session!=null) return ((HttpSessionFacade)session).getCachedSession();
+	return null;
+    }
 }
